@@ -3,27 +3,34 @@ use Spoon::Base -Base;
 
 const class_id => 'hub';
 const action => '_default_';
-field -weak => 'main';
-field 'config';
-field 'registry';
-field 'config_files' => [];
-field 'loaded_objects' => [];
-field 'post_process_actions' => [];
 
-sub load_registry {
-    return if $self->registry_loaded;
-    $self->load_class('registry');
-    $self->registry->load(@_);
-}
+field main => -weak;
+field hub => -weak,
+      -init => '$self';
+field config =>
+      -init => '$self->load_class("config")';
+field registry =>
+      -init => '$self->load_class("registry")';
 
-sub registry_loaded {
-    defined $self->registry &&
-    defined $self->registry->lookup;
+field config_files => [];
+field loaded_objects => [];
+field all_hooks => [];
+
+our $AUTOLOAD;
+sub AUTOLOAD {
+    $AUTOLOAD =~ /.*::(.*)/
+      or die "Can't AUTOLOAD '$AUTOLOAD'";
+    my $class_id = $1;
+    return if $class_id eq 'DESTROY';
+    field $class_id => 
+          -init => "\$self->load_class('$class_id')";
+    $self->$class_id(@_);
 }
 
+sub pre_process {}
+sub post_process {}
 
 sub process {
-    $self->load_registry;
     $self->preload;
     my $action = $self->action;
     die "No plugin for action '$action'"
@@ -31,12 +38,11 @@ sub process {
     my ($class_id, $method) = 
       @{$self->registry->lookup->action->{$action}};
     $method ||= $action;
-    $self->load_class($class_id);
-    $self->$class_id->pre_process;
     return $self->$class_id->$method;
 }
 
 sub preload {
+    $self->registry->load;
     my $preload = $self->registry->lookup->preload;
     map {
         $self->load_class($_->[0])
@@ -46,21 +52,7 @@ sub preload {
         my %hash = @{$preload->{$_}}[1..$#{$preload->{$_}}];
         [$_, $hash{priority} || 0];
     } keys %$preload;
-}
-
-sub add_post_process {
-    push @{$self->post_process_actions}, [@_];
-}
-
-sub post_process {
-    for my $object (@{$self->loaded_objects}) {
-        $object->post_process;
-    }
-    for my $tuple (@{$self->post_process_actions}) {
-        my ($class, $method, @args) = @$tuple;
-        $self->load_class($class);
-        $self->$class->$method(@args);
-    }
+    return $self;
 }
 
 sub cleanup {
@@ -71,6 +63,7 @@ sub cleanup {
     #XXX Maybe need to undef class_id fields for other loaded classes
 }
 
+# XXX Slated for oblivion. Not called anywhere apparently.
 sub require_class {
     my $class_id = shift;
     my $class_id_class = "${class_id}_class";
@@ -84,15 +77,17 @@ sub load_class {
     my ($class_id) = @_;
     return $self if $class_id eq 'hub';
     return $self->$class_id 
-      if $self->can($class_id) and defined $self->$class_id;
+      if $self->can($class_id) and defined $self->{$class_id};
     my $class_class = $class_id . '_class';
+    my $registry = $self->{registry};
     my $class_name = $self->config->can($class_class)
         ? $self->config->$class_class
-        : defined $self->registry
-          ? (defined $self->registry->lookup and
-             UNIVERSAL::isa($self->registry->lookup, 'Spoon::Lookup')
+        : defined $registry
+          ? (defined $registry->lookup and
+             UNIVERSAL::isa($registry->lookup,
+                            $registry->lookup_class)
             )
-            ? $self->registry->lookup->classes->{$class_id}
+            ? $registry->lookup->classes->{$class_id}
             : Carp::confess "Can't find a class for class_id '$class_id'"
           : Carp::confess "Can't find a class for class_id '$class_id'";
     $self->create_class_object($class_name, $class_id);
@@ -104,13 +99,16 @@ sub create_class_object {
       unless $class_name;
     eval "require $class_name" unless $class_name->can('new');
     die $@ if $@;
-    $self->add_hooks($class_name);
-    my $object = $class_name->new(hub => $self);
+    $self->add_hooks($class_name)
+      unless $class_id eq 'hooks';
+    my $object = $class_name->new(hub => $self)
+      or die "Can't create new '$class_name' object";
     push @{$self->loaded_objects}, $object;
     $class_id ||= $object->class_id;
     die "No class_id defined for class: '$class_name'\n"
       unless $class_id;
-    field $class_id;
+    field $class_id => 
+          -init => "\$self->load_class('$class_id')";
     $self->$class_id($object);
     $object->init;
     return $object;
@@ -122,13 +120,35 @@ sub add_hooks {
       or return;
     for my $class_name (keys %$hooks) {
         next unless $class_name->can('new');
-        hook(@$_) for @{$hooks->{$class_name} || []};
+        $self->add_hook(@$_) for @{$hooks->{$class_name} || []};
         delete $hooks->{$class_name};
     }
     delete $self->registry->lookup->{hook}
       if not keys %$hooks;
 }
 
+sub add_hook {
+    my $hooks = $self->all_hooks;
+    push @$hooks, $self->hooks->add(@_);
+    return $hooks->[-1];
+}
+
+sub remove_hooks {
+    my $hooks = $self->all_hooks;
+    while (@$hooks) {
+        pop(@$hooks)->unhook;
+    }
+}
+
+sub registry_loaded {
+    defined $self->{registry} &&
+    defined $self->{registry}->lookup;
+}
+
+sub DESTROY {
+    $self->remove_hooks;
+}
+
 __END__
 
 =head1 NAME 
