@@ -4,7 +4,6 @@ use IO::All; #XXX migrate to non-spiffy class
 
 const extract_to => '.';
 field quiet => 0;
-field 'hub';
 
 sub compress_from {
     $self->extract_to;
@@ -173,7 +172,7 @@ sub compress_lib {
             +{ "${class_id}_class" => $class_name }
         );
         warn "Compressing $class_name\n" unless $self->quiet;
-        $self->hub->load_class($class_id)->compress_files($source_dir);
+        $self->hub->$class_id->compress_files($source_dir);
     }
     grep {
         my $name = $_;
